@@ -141,8 +141,8 @@ sub can {
 	}
 
 	if($self->template_isset) {
-		my $method = shift;
-		return sub { shift; $self->$method(@_) };
+		my $template = $self->template;
+		return $template->can(@_);
 	}
 
 	return undef;
