@@ -1,5 +1,8 @@
 package KVM::Kavoom::Config::Common;
 
+use IO::File;
+use Guard;
+
 use KVM::Kavoom::Config -self;
 
 field disks => [];
@@ -15,6 +18,7 @@ merge logical_block_size => undef;
 merge physical_block_size => undef;
 merge serialport => 0;
 merge mem => undef;
+merge hugepages => undef;
 merge cpus => undef;
 merge acpi => 1;
 merge usb => 0;
@@ -27,12 +31,45 @@ merge statedir;
 merge rundir;
 merge kvm;
 
-field hugepages => undef;
-
 sub set_mem {
 	$self->mem(int(shift));
 }
 
+sub set_hugepages {
+	my $value = shift;
+	if($value eq '') {
+		$self->hugepages('');
+	} else {
+		my $mtab = new IO::File('/proc/mounts', '<')
+			or die "open(/proc/mounts): $!\n";
+
+		scope_guard { $mtab->close };
+
+		my $wrong = "filesystem non-existent or not mounted";
+
+		local $_;
+		while(defined($_ = $mtab->getline)) {
+			chomp;
+			my ($device, $mountpoint, $type) = split();
+			next unless defined $type;
+			next if ord($device) == 35; #
+
+			$mountpoint =~ s{\\([0-7]{3})}{chr(oct($1))}aeg;
+			next if $mountpoint ne $value;
+
+			$wrong = "not a hugetlbfs filesystem";
+
+			$type =~ s{\\([0-7]{3})}{chr(oct($1))}aeg;
+			next if $type ne 'hugetlbfs';
+
+			$self->hugepages($value);
+			return;
+		}
+
+		die "'$value': $wrong\n";
+	}
+}
+
 sub set_cpus {
 	$self->cpus(int(shift));
 }
